@@ -29,7 +29,14 @@ Database Stuff
 from sqlalchemy.orm import sessionmaker, scoped_session
 
 
-__all__ = ['Session']
-
-
 Session = scoped_session(sessionmaker())
+
+
+try:
+    # Requires zope.sqlalchemy >= 0.7.4
+    from zope.sqlalchemy import register
+except ImportError:
+    from zope.sqlalchemy import ZopeTransactionExtension
+    Session.configure(extension=ZopeTransactionExtension())
+else:
+    register(Session)
